@@ -1,35 +1,43 @@
 # a bar plot with errorbars
+from matplotlib import pyplot as plt, use
 import numpy as np
-import matplotlib.pyplot as plt
+
 
 N = 5
 menMeans = (20, 35, 30, 35, 27)
-menStd =   (2, 3, 4, 1, 2)
+menStd = (2, 3, 4, 1, 2)
 
 ind = np.arange(N)  # the x locations for the groups
 width = 0.35       # the width of the bars
 
+
+use('module://backend_ipe')
+
 fig, ax = plt.subplots()
 rects1 = ax.bar(ind, menMeans, width, color='r', yerr=menStd)
 
 womenMeans = (25, 32, 34, 20, 25)
-womenStd =   (3, 5, 2, 3, 3)
+womenStd = (3, 5, 2, 3, 3)
 rects2 = ax.bar(ind+width, womenMeans, width, color='y', yerr=womenStd)
 
 # add some text for labels, title and axes ticks
 ax.set_ylabel('Scores')
 ax.set_title('Scores by group and gender')
 ax.set_xticks(ind+width)
-ax.set_xticklabels( ('G1', 'G2', 'G3', 'G4', 'G5') )
+ax.set_xticklabels(('G1', 'G2', 'G3', 'G4', 'G5'))
+
+ax.legend((rects1[0], rects2[0]), ('Men', 'Women'))
 
-ax.legend( (rects1[0], rects2[0]), ('Men', 'Women') )
 
 def autolabel(rects):
     # attach some text labels
     for rect in rects:
         height = rect.get_height()
-        ax.text(rect.get_x()+rect.get_width()/2., 1.05*height, '%d'%int(height),
-                ha='center', va='bottom')
+        ax.text(rect.get_x()+rect.get_width()/2., 1.05*height,
+                '%d' % int(height), ha='center', va='bottom')
+
 
 autolabel(rects1)
 autolabel(rects2)
+
+plt.savefig('barchart_demo.ipe', format='ipe')
