@@ -10,9 +10,13 @@ In addition to the basic fill plot, this demo shows a few optional features:
 """
 import numpy as np
 import matplotlib.pyplot as plt
+from matplotlib import use
+use('module://backend_ipe')
 
 x = np.linspace(0, 2 * np.pi, 100)
 y1 = np.sin(x)
 y2 = np.sin(3 * x)
 plt.fill(x, y1, 'b', x, y2, 'r', alpha=0.3)
 
+# plt.show()
+plt.savefig('fill_demo.ipe')
