@@ -3,6 +3,8 @@ import numpy as np
 import matplotlib.pyplot as plt
 import matplotlib.patches as patches
 import matplotlib.path as path
+from matplotlib import use
+use('module://backend_ipe')
 
 fig, ax = plt.subplots()
 
@@ -19,17 +21,19 @@ top = bottom + n
 
 # we need a (numrects x numsides x 2) numpy array for the path helper
 # function to build a compound path
-XY = np.array([[left,left,right,right], [bottom,top,top,bottom]]).T
+XY = np.array([[left, left, right, right], [bottom, top, top, bottom]]).T
 
 # get the Path object
 barpath = path.Path.make_compound_path_from_polys(XY)
 
 # make a patch out of it
-patch = patches.PathPatch(barpath, facecolor='blue', edgecolor='gray', alpha=0.8)
+patch = patches.PathPatch(barpath, facecolor='blue', edgecolor='gray',
+                          alpha=0.8)
 ax.add_patch(patch)
 
 # update the view limits
 ax.set_xlim(left[0], right[-1])
 ax.set_ylim(bottom.min(), top.max())
 
-
+# plt.show()
+plt.savefig('histogram_path_demo.ipe')
