@@ -4,6 +4,8 @@ Demo of image that's been clipped by a circular patch.
 import matplotlib.pyplot as plt
 import matplotlib.patches as patches
 import matplotlib.cbook as cbook
+from matplotlib import use
+use('module://backend_ipe')
 
 datafile = cbook.get_sample_data('grace_hopper.jpg', asfileobj=False)
 image = plt.imread(datafile)
@@ -13,3 +15,5 @@ patch = patches.Circle((260, 200), radius=200, transform=ax.transData)
 im.set_clip_path(patch)
 
 plt.axis('off')
+# plt.show()
+plt.savefig('image_demo_clip_path.ipe')
