@@ -1,10 +1,13 @@
-
 import numpy as np
 import matplotlib.pyplot as plt
+import matplotlib as mpl
+mpl.use('module://backend_ipe')
+
+
 mpl.rcParams['ipe.textsize'] = True
 
 # Make some fake data.
-a = b = np.arange(0,3, .02)
+a = b = np.arange(0, 3, .02)
 c = np.exp(a)
 d = c[::-1]
 
@@ -18,3 +21,4 @@ legend = plt.legend(loc='upper center', shadow=True, fontsize='x-large')
 # Put a nicer background color on the legend.
 legend.get_frame().set_facecolor('#00FFCC')
 
+plt.savefig('legend_demo.ipe')
