@@ -1,4 +1,3 @@
-
 """
 Use a PNG file as a watermark
 """
@@ -6,6 +5,10 @@ import numpy as np
 import matplotlib.cbook as cbook
 import matplotlib.image as image
 import matplotlib.pyplot as plt
+from matplotlib import use
+
+
+use('module://backend_ipe')
 
 datafile = cbook.get_sample_data('logo2.png', asfileobj=False)
 im = image.imread(datafile)
@@ -16,3 +19,5 @@ fig, ax = plt.subplots()
 ax.plot(np.random.rand(20), '-o', ms=20, lw=2, alpha=0.7, mfc='orange')
 ax.grid()
 fig.figimage(im, 10, 10)
+#plt.show()
+plt.savefig('watermark_image2.ipe')
