@@ -290,21 +290,28 @@ void XmlOutputDev::startText(GfxState *state, double x, double y)
   double xt, yt;
   state->transform(x, y, &xt, &yt);
 
-  const double *T = state->getTextMat();
-  const double *C = state->getCTM();
+#if POPPLER_VERSION_AT_LEAST(26, 2, 0)
+  const auto &T = state->getTextMat();
+  const auto &C = state->getCTM();
+  const double *Tp = T.data();
+  const double *Cp = C.data();
+#else
+  const double *Tp = state->getTextMat();
+  const double *Cp = state->getCTM();
+#endif
 
   /*
   fprintf(stderr, "TextMatrix = %g %g %g %g %g %g\n", 
-	  T[0], T[1], T[2], T[3], T[4], T[5]);
+	  Tp[0], Tp[1], Tp[2], Tp[3], Tp[4], Tp[5]);
   fprintf(stderr, "CTM = %g %g %g %g %g %g\n", 
-	  C[0], C[1], C[2], C[3], C[4], C[5]);
+	  Cp[0], Cp[1], Cp[2], Cp[3], Cp[4], Cp[5]);
   */
 
   double M[4];
-  M[0] = C[0] * T[0] + C[2] * T[1];
-  M[1] = C[1] * T[0] + C[3] * T[1];
-  M[2] = C[0] * T[2] + C[2] * T[3];
-  M[3] = C[1] * T[2] + C[3] * T[3];
+  M[0] = Cp[0] * Tp[0] + Cp[2] * Tp[1];
+  M[1] = Cp[1] * Tp[0] + Cp[3] * Tp[1];
+  M[2] = Cp[0] * Tp[2] + Cp[2] * Tp[3];
+  M[3] = Cp[1] * Tp[2] + Cp[3] * Tp[3];
 
   GfxRGB rgb;
   state->getFillRGB(&rgb);
@@ -345,13 +352,18 @@ void XmlOutputDev::drawImage(GfxState *state, Object *ref, Stream *str,
   GfxRGB rgb;
   int x, y;
   int c;
+  GfxColorSpaceMode colormode = colorMap->getColorSpace()->getMode();
 
   writePSFmt("<image width=\"%d\" height=\"%d\"", width, height);
 
+#if POPPLER_VERSION_AT_LEAST(26, 2, 0)
+  const auto &matArr = state->getCTM();
+  const double *mat = matArr.data();
+#else
   const double *mat = state->getCTM();
-  double tx = mat[0] + mat[2] + mat[4];
-  double ty = mat[1] + mat[3] + mat[5];
-  writePSFmt(" rect=\"%g %g %g %g\"", mat[4], mat[5], tx, ty);
+#endif
+  writePSFmt(" rect=\"0 1 1 0\" matrix=\"%g %g %g %g %g %g\"",
+      mat[0], mat[1], mat[2], mat[3], mat[4], mat[5]);
   
   if (str->getKind() == strDCT && !inlineImg &&
       3 <= colorMap->getNumPixelComps() && colorMap->getNumPixelComps() <= 4) {
@@ -359,7 +371,11 @@ void XmlOutputDev::drawImage(GfxState *state, Object *ref, Stream *str,
     std::vector<char> buffer;
     // initialize stream
     str = str->getNextStream();
+  #if POPPLER_VERSION_AT_LEAST(26, 1, 0)
+    str->rewind();
+  #else
     str->reset();
+  #endif
     // copy the stream
     while ((c = str->getChar()) != EOF)
       buffer.push_back(char(c));
@@ -382,7 +398,11 @@ void XmlOutputDev::drawImage(GfxState *state, Object *ref, Stream *str,
     // 1 bit depth -- not implemented in Ipe
 
     // initialize stream
+  #if POPPLER_VERSION_AT_LEAST(26, 1, 0)
+    str->rewind();
+  #else
     str->reset();
+  #endif
     // copy the stream
     size = height * ((width + 7) / 8);
     for (i = 0; i < size; ++i) {
@@ -390,7 +410,7 @@ void XmlOutputDev::drawImage(GfxState *state, Object *ref, Stream *str,
     }
     str->close();
 #endif
-  } else if (colorMap->getNumPixelComps() == 1) {
+  } else if (colormode == csDeviceGray || colormode == csCalGray) {
     // write as gray level image
     writePS(" ColorSpace=\"DeviceGray\"");
     writePS(" BitsPerComponent=\"8\"");
@@ -399,7 +419,11 @@ void XmlOutputDev::drawImage(GfxState *state, Object *ref, Stream *str,
     // initialize stream
     imgStr = new ImageStream(str, width, colorMap->getNumPixelComps(),
 			     colorMap->getBits());
+  #if POPPLER_VERSION_AT_LEAST(26, 1, 0)
+    imgStr->rewind();
+  #else
     imgStr->reset();
+  #endif
     
     // for each line...
     for (y = 0; y < height; ++y) {
@@ -424,7 +448,11 @@ void XmlOutputDev::drawImage(GfxState *state, Object *ref, Stream *str,
     // initialize stream
     imgStr = new ImageStream(str, width, colorMap->getNumPixelComps(),
 			     colorMap->getBits());
+  #if POPPLER_VERSION_AT_LEAST(26, 1, 0)
+    imgStr->rewind();
+  #else
     imgStr->reset();
+  #endif
     
     // for each line...
     for (y = 0; y < height; ++y) {
